:root {
    --success-bg-color: hsl(132, 32%, 36%);
    --success-text-color: hsl(0, 0%, 96%);
    --success-svg-color: hsl(0, 0%, 96%);
    --info-bg-color: hsl(220, 61%, 52%);
    --info-text-color: hsl(0, 0%, 96%);
    --info-svg-color: hsl(0, 0%, 96%);
    --warning-bg-color: hsl(48, 100%, 62%);
    --warning-text-color: hsl(0, 0%, 14%);
    --warning-svg-color: hsl(0, 0%, 25%);
    --error-bg-color: hsl(0, 100%, 37%);
    --error-text-color: hsl(0, 2%, 92%);
    --error-svg-color: hsl(0, 2%, 92%);
}

.django_messages_display_messages_container {
    list-style-type: none;
    position: fixed;
    top: 1rem;
    right: 1rem;
    width: 20rem;
    z-index: 1000;

    display: flex;
    flex-direction: column;
    gap: 1rem;

    font-size: 0.875rem;
    line-height: 1.25rem;
}

.django_messages_display_messages_container.hidden {
    pointer-events: none;
}


.django_messages_display_messages_container>li {
    border-radius: 0.25rem;
    display: flex;
    align-items: center;
    justify-content: space-between;
    box-shadow: 0 1px 3px 0 hsla(0, 0%, 0%, 0.1), 0 1px 2px -1px hsla(0, 0%, 0%, 0.1);
    transition: opacity 0.3s linear, transform 0.3s ease-out;
}

.django_messages_display_messages_container>li.hidden {
    opacity: 0;
    transform: translate(3em, 0);
    pointer-events: none;
}

.django_messages_display_messages_container>li.hidden>button {
    visibility: hidden;
}

.django_messages_display_messages_container>li.success {
    background-color: var(--success-bg-color);
}

.django_messages_display_messages_container>li.success>p {
    color: var(--success-text-color);
}

.django_messages_display_messages_container>li.success>button>svg {
    color: var(--success-svg-color);
}

.django_messages_display_messages_container>li.info {
    background-color: var(--info-bg-color);
}

.django_messages_display_messages_container>li.info>p {
    color: var(--info-text-color);
}

.django_messages_display_messages_container>li.info>button>svg {
    color: var(--info-svg-color);
}

.django_messages_display_messages_container>li.warning {
    background-color: var(--warning-bg-color);
}

.django_messages_display_messages_container>li.warning>p {
    color: var(--warning-text-color);
}

.django_messages_display_messages_container>li.warning>button>svg {
    color: var(--warning-svg-color);
}

.django_messages_display_messages_container>li.error {
    background-color: var(--error-bg-color);
}

.django_messages_display_messages_container>li.error>p {
    color: var(--error-text-color);
}

.django_messages_display_messages_container>li.error>button>svg {
    color: var(--error-svg-color);
}

.django_messages_display_messages_container>li>p {
    padding: 0rem 1rem;
    margin: 1rem 0rem;
}

.django_messages_display_messages_container>li>button {
    all: unset;
    cursor: pointer;
    margin-right: 0.5rem;
    margin-top: 1rem;
    display: inline-flex;
    align-items: center;
    align-self: start;
}

.django_messages_display_messages_container>li>button>svg {
    width: 1.25rem;
    height: 1.25rem;
}